"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.145
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.submit_self_service_settings_flow_with_lookup_method_body import SubmitSelfServiceSettingsFlowWithLookupMethodBody
from ory_client.model.submit_self_service_settings_flow_with_oidc_method_body import SubmitSelfServiceSettingsFlowWithOidcMethodBody
from ory_client.model.submit_self_service_settings_flow_with_password_method_body import SubmitSelfServiceSettingsFlowWithPasswordMethodBody
from ory_client.model.submit_self_service_settings_flow_with_profile_method_body import SubmitSelfServiceSettingsFlowWithProfileMethodBody
from ory_client.model.submit_self_service_settings_flow_with_totp_method_body import SubmitSelfServiceSettingsFlowWithTotpMethodBody
from ory_client.model.submit_self_service_settings_flow_with_web_authn_method_body import SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody
globals()['SubmitSelfServiceSettingsFlowWithLookupMethodBody'] = SubmitSelfServiceSettingsFlowWithLookupMethodBody
globals()['SubmitSelfServiceSettingsFlowWithOidcMethodBody'] = SubmitSelfServiceSettingsFlowWithOidcMethodBody
globals()['SubmitSelfServiceSettingsFlowWithPasswordMethodBody'] = SubmitSelfServiceSettingsFlowWithPasswordMethodBody
globals()['SubmitSelfServiceSettingsFlowWithProfileMethodBody'] = SubmitSelfServiceSettingsFlowWithProfileMethodBody
globals()['SubmitSelfServiceSettingsFlowWithTotpMethodBody'] = SubmitSelfServiceSettingsFlowWithTotpMethodBody
globals()['SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody'] = SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody
from ory_client.model.submit_self_service_settings_flow_body import SubmitSelfServiceSettingsFlowBody


class TestSubmitSelfServiceSettingsFlowBody(unittest.TestCase):
    """SubmitSelfServiceSettingsFlowBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSubmitSelfServiceSettingsFlowBody(self):
        """Test SubmitSelfServiceSettingsFlowBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SubmitSelfServiceSettingsFlowBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
